<!-- An a5 sheet with login info and hashcode to sign and hand in -->
{% from "macros/hashcode_table.html" import hashcode_table %}

<link rel="stylesheet" href="../../css/container.css" />
<link rel="stylesheet" href="../../css/elements.css" />

<div class="a5-container-horizontal">
  <div class="header">
    <h2>{{ labels.hand_in_label }}</h2>
    <h3>{{ exam_info.exam_name }}</h3>
  </div>
  <div class="info-table">
    <table>
      <tr>
        <th scope="col">{{ labels.room_label }}:</th>
        <td>{{ student.room }}&nbsp;/&nbsp;{{ student.seat }}</td>
        <td class="spacer"></td>
        <th scope="col">{{ labels.date_label }}:</th>
        <td>{{ exam_info.date }}</td>
      </tr>
      <tr>
        <th scope="row">Name:</th>
        <td colspan="4">
          {{ student.first_name }}&nbsp;{{ student.last_name }}
        </td>
      </tr>
    </table>
  </div>
  <div class="login-box">
    <span class="login-info-header">Login Info</span>
    <table>
      <tr>
        <th id="username-label">{{ labels.username_label }}:</th>
        <td class="spacer"></td>
        <td>{{ student.username }}</td>
      </tr>
      <tr>
        <th id="password-label">{{ labels.password_label }}:</th>
        <td class="spacer"></td>
        <td>{{ student.password }}</td>
      </tr>
    </table>
  </div>
  <div class="fill-in">
    <h4 class="header">{{ labels.fill_in_label }}</h4>
    <table class="hashcode_table">
      {{ hashcode_table(exam_info.hashcode_num_blocks,
      exam_info.hashcode_block_size) }}
      <tr class="vspace"></tr>
      <tr>
        <th id="signature-label">{{ labels.signature_label }}:</th>
        <td class="spacer"></td>
        <td colspan="14" class="signature-line"></td>
      </tr>
      <tr>
        <th scope="row"></th>
        <td class="spacer"></td>
        <td colspan="14" class="signature-name">
          {{ student.first_name }}&nbsp;{{ student.last_name }}
        </td>
      </tr>
    </table>
  </div>
</div>
