<!-- Macro to generate a table for hashcodes. -->
{% macro hashcode_table(blocks, chars_per_block) %}
<tr style="padding-left: 10mm">
  <th scope="col">Hashcode:</th>
  <td class="spacer"></td>
  {% for block in range(blocks) %} {% for char in range(chars_per_block) %}
  <td class="hashcode-char"></td>
  {% endfor %} {% if not loop.last %}
  <td class="hashcode-dash">-</td>
  {% endif %} {% endfor %}
</tr>
{% endmacro %}
