.line-a4 {
  display: block;
  padding-top: 5mm;
  text-align: center;
  overflow-wrap: break-word;
  max-width: 13cm;
  margin: 0 auto;
}
.seating_card_container {
  padding-top: 10mm;
  display: grid;
  place-items: center;
  width: 100%;
}
.seating_card {
  display: grid;
  grid-auto-flow: row;
  height: 100%;
}
