.cut-line {
  border-top: 3px dashed #000;
  position: absolute;
  top: 148.5mm;
  width: 200mm;
  margin-left: 7mm;
}
.cut-line:before {
  content: "\2702"; /* This is the HTML entity for scissors */
  position: absolute;
  top: -23px;
  left: -20px;
  font-size: 30px;
}
.fill-in table {
  margin: 0 auto;
  border-collapse: collapse;
}
.vspace {
  height: 10mm;
  box-sizing: border-box;
  display: inline-block;
}
.header {
  text-align: center;
}
.exam_sheet_info {
  font-size: 12px;
  margin-bottom: 5mm;
}
.exam_sheet_info td {
  padding-right: 5mm;
}
.overview_table {
  font-size: 14px;
  border-collapse: collapse;
  min-width: 150mm;
}
.overview_table th,
.overview_table td {
  border: 1px solid black;
  padding-right: 10px;
  padding-left: 10px;
  overflow-wrap: break-word;
}
.fill-space {
  width: 100%;
}
.info-table {
  width: 11cm;
  margin: 0 auto;
}
.info-table table {
  width: 100%;
}
th,
td {
  text-align: left;
  border: none;
  padding: 0;
  margin: 0;
}
.login-box {
  border: 1mm solid #ccc;
  border-radius: 3mm;

  padding: 5mm;
  padding-top: 2mm;
  box-sizing: border-box;
  margin: 0 auto;
  margin-top: 8mm;
  width: 11cm;
  text-align: center;
}
.login-box table {
  margin: 0 auto;
  margin-top: 2mm;
}
.spacer {
  width: 1cm;
}
.signature-name {
  text-align: center;
  font-size: 12px;
}
.signature-line {
  border-bottom: 1px solid black;
}
