<!-- An a5 sheet containing the hashcode for students to take home-->
{% from "macros/hashcode_table.html" import hashcode_table %}

<link rel="stylesheet" href="../../css/container.css" />
<link rel="stylesheet" href="../../css/elements.css" />

<div class="a5-container-horizontal">
  <div class="header">
    <h2>{{ labels.take_home_label }}</h2>
    <h3>{{ exam_info.exam_name }}</h3>
  </div>
  <div class="info-table">
    <table>
      <tr>
        <th scope="col">{{ labels.room_label }}:</th>
        <td>{{ student.room }}</td>
        <td class="spacer"></td>
        <th scope="col">{{ labels.date_label }}:</th>
        <td>{{ exam_info.date }}</td>
      </tr>
      <tr>
        <th scope="row">Name:</th>
        <td colspan="4">
          {{ student.first_name }}&nbsp;{{ student.last_name }}
        </td>
      </tr>
    </table>
  </div>
  <div style="height: 2cm"></div>
  <div class="fill-in">
    <h4 class="header">{{ labels.fill_in_label }}</h4>
    <table class="hashcode_table">
      {{ hashcode_table(exam_info.hashcode_num_blocks,
      exam_info.hashcode_block_size) }}
    </table>
  </div>
</div>
