.overview_table {
  font-size: 14px;
  border-collapse: collapse;
  min-width: 150mm;
}
.overview_table th,
.overview_table td {
  border: 1px solid black;
  padding-right: 10px;
  padding-left: 10px;
}
.exam_sheet_info {
  font-size: 12px;
  margin-bottom: 5mm;
}
.exam_sheet_info td {
  padding-right: 5mm;
}
