<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="UTF-8" />
    <style>{{ css }}</style>
    <title>Exam Sheet</title>
  </head>
  <body>
    {% set students_sorted_by_seat = students | sort(attribute='seat') %}
    {% if add_empty_page %}
    <div class="a4-container"><!-- Empty page --></div>
    {% endif %}
    {% for student in students_sorted_by_seat %}    
    <div class="a4-container">
      {% include "sheets/seating_sheet.html" %}
      <div class="cut-line"></div>
      {% include "sheets/login_sheet.html" %}
    </div>
    <div class="a4-container">
      {% include "sheets/take_home_sheet.html" %}
      <div class="cut-line"></div>
      {% include "sheets/notes_sheet.html" %}
    </div>
    {% endfor %}
  </body>
</html>
