<!-- An a5 sheet with seat number and student name -->
<link rel="stylesheet" href="../../css/container.css" />
<link rel="stylesheet" href="../../css/seating_card.css" />

<div class="a5-container-horizontal">
  <div class="seating_card_container">
    <div class="seating_card">
      <span class="line-a4" style="font-weight: bold; font-size: 12mm;"
        >{{ student.last_name }}</span
      >
      <span class="line-a4" style="font-size: 10mm"
        >{{ student.first_name }}</span
      >
      <span class="line-a4" style="font-size: 5mm; white-space: no-wrap"
        >{{ exam_info.exam_name }}</span
      >
      <span class="line-a4" style="font-weight: bold; font-size: 12mm"
        >{{ student.room }}</span
      >
      <span class="line-a4" style="font-weight: bold; font-size: 12mm"
        >{{ labels.seat_label }}&nbsp;{{ student.seat }}</span
      >
    </div>
  </div>
</div>
